<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>AddPluginDialog</name>
    <message>
        <location filename="../../../config/addplugindialog.ui" line="14"/>
        <source>Add Plugins</source>
        <translation>Προσθήκη πρόσθετων</translation>
    </message>
    <message>
        <location filename="../../../config/addplugindialog.ui" line="22"/>
        <source>Search:</source>
        <translation>Αναζήτηση:</translation>
    </message>
    <message>
        <location filename="../../../config/addplugindialog.ui" line="98"/>
        <source>Add Widget</source>
        <translation>Προσθήκη γραφικού συστατικού</translation>
    </message>
    <message>
        <location filename="../../../config/addplugindialog.ui" line="105"/>
        <source>Close</source>
        <translation>Κλείσιμο</translation>
    </message>
    <message>
        <location filename="../../../config/addplugindialog.cpp" line="115"/>
        <source>(only one instance can run at a time)</source>
        <translation>(δεν επιτρέπονται περισσότερες από μια εκτελέσεις ταυτόχρονα)</translation>
    </message>
</context>
<context>
    <name>ConfigPanelDialog</name>
    <message>
        <source>Configure panel</source>
        <translation type="vanished">Διαμόρφωση του πίνακα</translation>
    </message>
    <message>
        <source>Panel size</source>
        <translation type="vanished">Μέγεθος του πίνακα</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation type="vanished">Μέγεθος:</translation>
    </message>
    <message>
        <source>px</source>
        <translation type="vanished">εικ</translation>
    </message>
    <message>
        <source>Use automatic sizing</source>
        <translation type="vanished">Χρήση του αυτόματου μεγέθους</translation>
    </message>
    <message>
        <source>Panel length &amp;&amp; position</source>
        <translation type="vanished">Μήκος &amp;&amp; θέση του πίνακα</translation>
    </message>
    <message>
        <source>Left</source>
        <translation type="vanished">Αριστερά</translation>
    </message>
    <message>
        <source>Center</source>
        <translation type="vanished">Κέντρο</translation>
    </message>
    <message>
        <source>Right</source>
        <translation type="vanished">Δεξιά</translation>
    </message>
    <message>
        <source>%</source>
        <translation type="vanished">%</translation>
    </message>
    <message>
        <source>Alignment:</source>
        <translation type="vanished">Στοίχιση:</translation>
    </message>
    <message>
        <source>Length:</source>
        <translation type="vanished">Μήκος:</translation>
    </message>
    <message>
        <source>Position:</source>
        <translation type="vanished">Θέση:</translation>
    </message>
    <message>
        <source>Top of desktop</source>
        <translation type="vanished">Στην κορυφή της επιφάνεια εργασίας</translation>
    </message>
    <message>
        <source>Left of desktop</source>
        <translation type="vanished">Στα αριστερά της επιφάνειας εργασίας</translation>
    </message>
    <message>
        <source>Right of desktop</source>
        <translation type="vanished">Στα δεξιά της επιφάνειας εργασίας</translation>
    </message>
    <message>
        <source>Bottom of desktop</source>
        <translation type="vanished">Στη βάση της επιφάνειας εργασίας</translation>
    </message>
    <message>
        <source>Top of desktop %1</source>
        <translation type="vanished">Στην κορυφή της επιφάνειας εργασίας %1</translation>
    </message>
    <message>
        <source>Left of desktop %1</source>
        <translation type="vanished">Στα αριστερά της επιφάνειας εργασίας %1</translation>
    </message>
    <message>
        <source>Right of desktop %1</source>
        <translation type="vanished">Στα δεξιά της επιφάνειας εργασίας %1</translation>
    </message>
    <message>
        <source>Bottom of desktop %1</source>
        <translation type="vanished">Στη βάση της επιφάνειας εργασίας %1</translation>
    </message>
    <message>
        <location filename="../../../config/configpaneldialog.cpp" line="31"/>
        <source>Configure Panel</source>
        <translation>Διαμόρφωση του πίνακα</translation>
    </message>
    <message>
        <location filename="../../../config/configpaneldialog.cpp" line="38"/>
        <source>Panel</source>
        <translation>Πίνακας</translation>
    </message>
    <message>
        <location filename="../../../config/configpaneldialog.cpp" line="42"/>
        <source>Widgets</source>
        <translation>Γραφικά συστατικά</translation>
    </message>
</context>
<context>
    <name>ConfigPanelWidget</name>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="20"/>
        <source>Configure panel</source>
        <translation>Διαμόρφωση του πίνακα</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="44"/>
        <source>Size</source>
        <translation>Μέγεθος</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="81"/>
        <source>Size:</source>
        <translation>Μέγεθος:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="109"/>
        <location filename="../../../config/configpanelwidget.ui" line="153"/>
        <source> px</source>
        <translation> εικ</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="166"/>
        <source>Icon size:</source>
        <translation>Μέγεθος εικονιδίων:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="88"/>
        <source>Length:</source>
        <translation>Μήκος:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="68"/>
        <source>&lt;p&gt;Negative pixel value sets the panel length to that many pixels less than available screen space.&lt;/p&gt;&lt;p/&gt;&lt;p&gt;&lt;i&gt;E.g. &quot;Length&quot; set to -100px, screen size is 1000px, then real panel length will be 900 px.&lt;/i&gt;&lt;/p&gt;</source>
        <translation>&lt;p&gt;Μια αρνητική τιμή εικονοστοιχείων θέτει το μήκος του πίνακα σε τόσα εικονοστοιχεία λιγότερο από τον διαθέσιμο χώρο της οθόνης.&lt;/p&gt;&lt;p/&gt;&lt;p&gt;&lt;i&gt;Π.χ. θέτοντας το «Μήκος» σε -100εικ, και με μέγεθος οθόνης 1000εικ, τότε το πραγματικό μήκος του πίνακα θα είναι 900 εικ.&lt;/i&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="96"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="101"/>
        <source>px</source>
        <translation>εικ</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="173"/>
        <source>Rows count:</source>
        <translation>Πλήθος γραμμών:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="202"/>
        <source>Alignment &amp;&amp; position</source>
        <translation>Στοίχιση &amp;&amp; θέση</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="262"/>
        <location filename="../../../config/configpanelwidget.ui" line="285"/>
        <source>Zero means no animation</source>
        <translation>Μηδέν σημαίνει χωρίς τέχνασμα κίνησης</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="288"/>
        <location filename="../../../config/configpanelwidget.ui" line="314"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="265"/>
        <source>Animation duration:</source>
        <translation>Διάρκεια του τεχνάσματος κίνησης:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="219"/>
        <location filename="../../../config/configpanelwidget.cpp" line="202"/>
        <source>Left</source>
        <translation>Αριστερά</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="224"/>
        <location filename="../../../config/configpanelwidget.cpp" line="203"/>
        <location filename="../../../config/configpanelwidget.cpp" line="209"/>
        <source>Center</source>
        <translation>Κέντρο</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="229"/>
        <location filename="../../../config/configpanelwidget.cpp" line="204"/>
        <source>Right</source>
        <translation>Δεξιά</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="250"/>
        <source>A&amp;uto-hide</source>
        <translation>Αυ&amp;τόματη απόκρυψη</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="301"/>
        <location filename="../../../config/configpanelwidget.ui" line="311"/>
        <source>Zero means no delay</source>
        <translation>Μηδέν σημαίνει χωρίς καθυστέρηση</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="304"/>
        <source>Show with delay:</source>
        <translation>Εμφάνιση με καθυστέρηση:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="330"/>
        <source>Don&apos;t allow maximized windows go under the panel window</source>
        <translation>Να μην επιτρέπεται στα μεγιστοποιημένα παράθυρα να καταλαμβάνουν τον χώρο κάτω από το πλαίσιο του πίνακα</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="333"/>
        <source>Reserve space on display</source>
        <translation>Δέσμευση χώρου στην απεικόνιση</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="349"/>
        <source>Custom styling</source>
        <translation>Προσαρμοσμένη τεχνοτροπία</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="370"/>
        <source>Font color:</source>
        <translation>Χρώμα γραμματοσειράς:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="410"/>
        <source>Background color:</source>
        <translation>Χρώμα φόντου:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="449"/>
        <source>Background opacity:</source>
        <translation>Αδιαφάνεια παρασκηνίου:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="481"/>
        <source>&lt;small&gt;Compositing is required for panel transparency.&lt;/small&gt;</source>
        <translation>&lt;small&gt;Για την διαφάνεια του πίνακα απαιτείται το χαρακτηριστικό γραφικών σύνθεσης.&lt;/small&gt;</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="509"/>
        <source>Background image:</source>
        <translation>Εικόνα παρασκηνίου:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="208"/>
        <source>Alignment:</source>
        <translation>Στοίχιση:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="237"/>
        <source>Position:</source>
        <translation>Θέση:</translation>
    </message>
    <message>
        <source>Auto-hide</source>
        <translation type="vanished">Αυτόματη απόκρυψη</translation>
    </message>
    <message>
        <source>Styling</source>
        <translation type="vanished">Τεχνοτροπία</translation>
    </message>
    <message>
        <source>Custom font color:</source>
        <translation type="vanished">Προσαρμοσμένο χρώμα γραμματοσειράς:</translation>
    </message>
    <message>
        <source>Custom background image:</source>
        <translation type="vanished">Προσαρμοσμένη εικόνα παρασκηνίου:</translation>
    </message>
    <message>
        <source>Custom background color:</source>
        <translation type="vanished">Προσαρμοσμένο χρώμα παρασκηνίου:</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation type="vanished">Αδιαφάνεια</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="168"/>
        <source>Top of desktop</source>
        <translation>Στην κορυφή της επιφάνεια εργασίας</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="169"/>
        <source>Left of desktop</source>
        <translation>Στα αριστερά της επιφάνειας εργασίας</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="170"/>
        <source>Right of desktop</source>
        <translation>Στα δεξιά της επιφάνειας εργασίας</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="171"/>
        <source>Bottom of desktop</source>
        <translation>Στη βάση της επιφάνειας εργασίας</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="180"/>
        <source>Top of desktop %1</source>
        <translation>Στην κορυφή της επιφάνειας εργασίας %1</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="181"/>
        <source>Left of desktop %1</source>
        <translation>Στα αριστερά της επιφάνειας εργασίας %1</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="182"/>
        <source>Right of desktop %1</source>
        <translation>Στα δεξιά της επιφάνειας εργασίας %1</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="183"/>
        <source>Bottom of desktop %1</source>
        <translation>Στη βάση της επιφάνειας εργασίας %1</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="208"/>
        <source>Top</source>
        <translation>Κορυφή</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="210"/>
        <source>Bottom</source>
        <translation>Βάση</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="368"/>
        <location filename="../../../config/configpanelwidget.cpp" line="384"/>
        <source>Pick color</source>
        <translation>Επιλέξτε το χρώμα</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="402"/>
        <source>Images (*.png *.gif *.jpg)</source>
        <translation>Εικόνες (*.png *.gif *.jpg)</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="402"/>
        <source>Pick image</source>
        <translation>Επιλογή εικόνας</translation>
    </message>
</context>
<context>
    <name>ConfigPluginsWidget</name>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="14"/>
        <source>Configure Plugins</source>
        <translation>Διαμόρφωση των πρόσθετων</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="84"/>
        <source>Note: changes made in this page cannot be reset.</source>
        <translation>Σημείωση: δεν είναι δυνατή η επαναφορά των αλλαγών αυτής της σελίδας.</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="112"/>
        <source>Move up</source>
        <translation>Μετακίνηση πάνω</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="115"/>
        <location filename="../../../config/configpluginswidget.ui" line="129"/>
        <location filename="../../../config/configpluginswidget.ui" line="150"/>
        <location filename="../../../config/configpluginswidget.ui" line="164"/>
        <location filename="../../../config/configpluginswidget.ui" line="185"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="126"/>
        <source>Move down</source>
        <translation>Μετακίνηση κάτω</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="147"/>
        <source>Add</source>
        <translation>Προσθήκη</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="161"/>
        <source>Remove</source>
        <translation>Αφαίρεση</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="182"/>
        <source>Configure</source>
        <translation>Διαμόρφωση</translation>
    </message>
</context>
<context>
    <name>LXQtPanel</name>
    <message>
        <source>Add Panel Widgets</source>
        <translation type="vanished">Προσθήκη γραφικών συστατικών του πίνακα</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1068"/>
        <location filename="../../../lxqtpanel.cpp" line="1094"/>
        <source>Panel</source>
        <translation>Πίνακας</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1097"/>
        <source>Configure Panel</source>
        <translation>Διαμόρφωση του πίνακα</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1102"/>
        <source>Manage Widgets</source>
        <translation>Διαχείριση των γραφικών συστατικών</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1108"/>
        <source>Add New Panel</source>
        <translation>Προσθήκη νέου πίνακα</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1115"/>
        <source>Remove Panel</source>
        <comment>Menu Item</comment>
        <translation>Αφαίρεση πίνακα</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1120"/>
        <source>Lock This Panel</source>
        <translation>Κλείδωμα του πίνακα</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1265"/>
        <source>Remove Panel</source>
        <comment>Dialog Title</comment>
        <translation>Αφαίρεση πίνακα</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1266"/>
        <source>Removing a panel can not be undone.
Do you want to remove this panel?</source>
        <translation>Η αφαίρεση ενός πίνακα δεν μπορεί να αναιρεθεί.
Θέλετε να αφαιρέσετε τον πίνακα;</translation>
    </message>
    <message>
        <source>Configure Panel...</source>
        <translation type="vanished">Διαμόρφωση του πίνακα...</translation>
    </message>
    <message>
        <source>Add Panel Widgets...</source>
        <translation type="vanished">Προσθήκη γραφικών συστατικών του πίνακα...</translation>
    </message>
    <message>
        <source>Add Panel</source>
        <translation type="vanished">Προσθήκη πίνακα</translation>
    </message>
    <message>
        <source>Remove Panel</source>
        <translation type="vanished">Αφαίρεση πίνακα</translation>
    </message>
    <message>
        <source>Configure panel...</source>
        <translation type="vanished">Διαμόρφωση του πίνακα...</translation>
    </message>
    <message>
        <source>Add plugins ...</source>
        <translation type="vanished">Προσθήκη πρόσθετων ...</translation>
    </message>
</context>
<context>
    <name>LXQtPanelPlugin</name>
    <message>
        <source>Configure</source>
        <translation type="vanished">Διαμόρφωση</translation>
    </message>
    <message>
        <source>Move</source>
        <translation type="vanished">Μετακίνηση</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="vanished">Αφαίρεση</translation>
    </message>
</context>
<context>
    <name>LXQtPanelPrivate</name>
    <message>
        <source>Configure panel</source>
        <translation type="vanished">Διαμόρφωση του πίνακα</translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <location filename="../../../plugin.cpp" line="416"/>
        <source>Configure &quot;%1&quot;</source>
        <translation>Διαμόρφωση του «%1»</translation>
    </message>
    <message>
        <location filename="../../../plugin.cpp" line="421"/>
        <source>Move &quot;%1&quot;</source>
        <translation>Μετακίνηση του «%1»</translation>
    </message>
    <message>
        <location filename="../../../plugin.cpp" line="429"/>
        <source>Remove &quot;%1&quot;</source>
        <translation>Αφαίρεση του «%1»</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../../../lxqtpanelapplication.cpp" line="95"/>
        <source>Use alternate configuration file.</source>
        <translation>Χρήση ενός εναλλακτικού αρχείου διαμόρφωσης.</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanelapplication.cpp" line="96"/>
        <source>Configuration file</source>
        <translation>Αρχείο διαμόρφωσης</translation>
    </message>
</context>
</TS>
